@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2023 Leandro Nini
+ * Copyright 2011-2024 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -113,14 +113,73 @@ uint16_t freqTableNtsc[]
 };
 #endif
 
-// This table contains chip-profiles which allow us to adjust
+// This tables contains chip-profiles which allow us to adjust
 // certain settings that varied wildly between 6581 chips, even
 // made in the same factory on the same day.
 //
 // This works under the assumption that the authors used the
 // same SID chip their entire career.
 //
-// based on https://github.com/reFX/libSidplayEZ/blob/modernized/src/chip-profiles.h
+// taken from https://github.com/reFX/libSidplayEZ/blob/modernized/src/chip-profiles.h
+#ifdef FEAT_FILTER_RANGE
+static const filter_map_t filterRangeMap =
+{
+    { "Anthony Lees",                        1.3 },
+    { "Antony Crowther (Ratt)",              1.1 },
+    { "Barry Leitch (The Jackal)",           0.05 },
+    { "Ben Daglish",                         0.6 },
+    { "Charles Deenen",                      0.2 },
+    { "Chris H\xFClsbeck",                   0.6 },
+    { "David Dunn",                          0.15 },
+    { "David Dunn & Aidan Bell",             0.15 },
+    { "David Whittaker",                     0.15 },
+    { "Thomas Mogensen (DRAX)",              0.3 },
+    { "Edwin van Santen",                    0.5 },
+    { "Edwin van Santen & Falco Paul",       0.4 }, // 20th Century Composers
+    { "Edwin van Santen & Venom",            0.4 }, // 20th Century Composers
+    { "Falco Paul",                          0.15 },
+    { "Falco Paul & Edwin van Santen",       0.4 }, // 20th Century Composers
+    { "Figge Wasberger (Fegolhuzz)",         0.25 },
+    { "Fred Gray",                           0.18 },
+    { "Geir Tjelta",                         0.5 },
+    { "Georg Feil",                          0.2 },
+    { "Glenn Rune Gallefoss",                0.2 },
+    { "Graham Jarvis & Rob Hartshorne",      0.25 },
+    { "Jason Page",                          0.35 },
+    { "Jeroen Tel",                          0.35 },
+    { "Johannes Bjerregaard",                0.35 },
+    { "Jonathan Dunn",                       0.25 },
+    { "Jouni Ikonen (Mixer)",                0.25 },
+    { "Jori Olkkonen",                       0.15 },
+    { "Jori Olkkonen (Yip)",                 0.15 },
+    { "Kim Christensen (Future Freak)",      0.35 },
+    { "Linus \xC5kesson (lft)",              0.3 },
+    { "Mark Cooksey",                        0.25 },
+    { "Markus M\xFCller (Superbrain)",       0.3 },
+    { "Martin Galway",                       1.0 },
+    { "Martin Walker",                       0.15 },
+    { "Matt Gray",                           0.3 },
+    { "Michael Hendriks",                    0.25 },
+    { "Mitch & Dane",                        0.75 },
+    { "M. Nilsson-Vonderburgh (Mic)",        0.25 },
+    { "M. Nilsson-Vonderburgh (Mitch)",      0.25 },
+    { "M. Nilsson-Vonderburgh (Yankee)",     0.25 },
+    { "Neil Brennan",                        0.25 },
+    { "Peter Clarke",                        0.2 },
+    { "Pex Tufvesson (Mahoney)",             0.35 },
+    { "Pex Tufvesson (Zax)",                 0.35 },
+    { "Renato Brosowski (Zoci-Joe)",         0.3 },
+    { "Reyn Ouwehand",                       0.25 },
+    { "Richard Joseph",                      0.3 },
+    { "Rob Hubbard",                         0.35 },
+    { "Russell Lieblich",                    0.25 },
+    { "Stellan Andersson (Dane)",            0.75 },
+    { "Steve Turner",                        0.6 },
+    { "Tim Follin",                          0.5 },
+    { "Thomas E. Petersen (Laxity)",         0.3 },
+    { "Thomas E. Petersen (TSS)",            0.3 },
+};
+#else
 static const filter_map_t filterCurveMap =
 {
     { "Anthony Lees",                        0.450 },
@@ -170,12 +229,26 @@ static const filter_map_t filterCurveMap =
     { "Thomas E. Petersen (Laxity)",         1.550 },
     { "Thomas E. Petersen (TSS)",            1.550 },
 };
+#endif
 
+#ifdef FEAT_FILTER_RANGE
+double getRecommendedFilterRange(const std::string& author)
+{
+    filter_map_iter_t it = filterRangeMap.find(author);
+    if (it != filterRangeMap.end())
+    {
+        double adjustment = it->second;
+        return (adjustment * 20. - 1.) / 39.;
+    }
+    return -1;
+}
+#else
 double getRecommendedFilterCurve(const std::string& author)
 {
     filter_map_iter_t it = filterCurveMap.find(author);
-    return (it != filterCurveMap.end()) ? it->second : 0.5;
+    return (it != filterCurveMap.end()) ? it->second : -1.;
 }
+#endif
 
 uint8_t* loadRom(const SID_STRING &romPath, const int size)
 {
@@ -300,7 +373,13 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         m_filter.enabled      = emulation.filter;
         m_filter.bias         = emulation.bias;
         m_filter.filterCurve6581 = emulation.filterCurve6581;
+#ifdef FEAT_FILTER_RANGE
+        m_filter.filterRange6581 = emulation.filterRange6581;
+#endif
         m_filter.filterCurve8580 = emulation.filterCurve8580;
+#ifdef FEAT_CW_STRENGTH
+        m_combinedWaveformsStrength = emulation.combinedWaveformsStrength;
+#endif
 
         if (emulation.powerOnDelay >= 0)
             m_engCfg.powerOnDelay    = emulation.powerOnDelay;
@@ -524,47 +603,54 @@ bool ConsolePlayer::createSidEmu (SIDEMUS emu, const SidTuneInfo *tuneInfo)
             rs->create ((m_engine.info ()).maxsids());
             if (!rs->getStatus()) goto createSidEmu_error;
 
+#ifdef FEAT_CW_STRENGTH
+            rs->combinedWaveformsStrength(m_combinedWaveformsStrength);
+#endif
+
+#ifdef FEAT_FILTER_RANGE
+            double frange = m_filter.filterRange6581;
+
+            if (m_autofilter && (tuneInfo->numberOfInfoStrings() == 3))
+            {
+                frange = getRecommendedFilterRange(tuneInfo->infoString(1));
+                if (m_verboseLevel > 1)
+                    cerr << "Recommended filter range: " << frange << endl;
+            }
+
+            if (m_verboseLevel)
+                cerr << "6581 filter range: " << frange << endl;
+            rs->filter6581Range(frange);
+#endif
+
             // 6581
-            double fcurve = -1.0;
+            double fcurve = m_filter.filterCurve6581;
+#ifndef FEAT_FILTER_RANGE
             if (m_autofilter && (tuneInfo->numberOfInfoStrings() == 3))
             {
                 fcurve = getRecommendedFilterCurve(tuneInfo->infoString(1));
                 if (m_verboseLevel > 1)
                     cerr << "Recommended filter curve: " << fcurve << endl;
             }
-            else if (m_fcurve >= 0.0)
-            {
-                fcurve = m_fcurve;
-            }
-            else if (m_filter.filterCurve6581 >= 0.0)
-            {
-                fcurve = m_filter.filterCurve6581;
-            }
-
-            if (fcurve >= 0.0)
-            {
-                if (m_verboseLevel)
-                    cerr << "6581 filter curve: " << fcurve << endl;
-                rs->filter6581Curve(fcurve);
-            }
-
-            // 8580
-            fcurve = -1.0;
+#endif
             if (m_fcurve >= 0.0)
             {
                 fcurve = m_fcurve;
             }
-            if (m_filter.filterCurve8580 >= 0.0)
+
+            if (m_verboseLevel)
+                cerr << "6581 filter curve: " << fcurve << endl;
+            rs->filter6581Curve(fcurve);
+
+            // 8580
+            fcurve = m_filter.filterCurve8580;
+            if (m_fcurve >= 0.0)
             {
-                fcurve = m_filter.filterCurve8580;
+                fcurve = m_fcurve;
             }
 
-            if (fcurve >= 0.0)
-            {
-                if (m_verboseLevel)
-                    cerr << "8580 filter curve: " << fcurve << endl;
-                rs->filter8580Curve(fcurve);
-            }
+            if (m_verboseLevel)
+                cerr << "8580 filter curve: " << fcurve << endl;
+            rs->filter8580Curve(fcurve);
         }
         catch (std::bad_alloc const &ba) {}
         break;
