@@ -128,6 +128,10 @@ private:
 
     double             m_fcurve;
 
+#ifdef FEAT_CW_STRENGTH
+    SidConfig::sid_cw_t m_combinedWaveformsStrength;
+#endif
+
     uint8_t            m_registers[3][32];
     uint16_t*          m_freqTable;
 
@@ -152,6 +156,9 @@ private:
         double         bias;
         // Filter parameters for reSIDfp
         double         filterCurve6581;
+#ifdef FEAT_FILTER_RANGE
+        double         filterRange6581;
+#endif
         double         filterCurve8580;
 
         bool           enabled;
